==> ssc-center-api-3.1.0-CLOUD-DEV-20230130.095227-2-sources.jar: com/tydic/dyc/ssc/service/scheme/bo/SscUpdateSchemeReqBO.java <==
package com.tydic.dyc.ssc.service.scheme.bo;

import lombok.Data;
import com.tydic.dyc.base.bo.BaseReqBo;
import com.tydic.dyc.ssc.service.scheme.bo.SscAccessoryBO;
import com.tydic.dyc.ssc.service.scheme.bo.SscSchemePackBO;
import java.math.BigDecimal;
import java.util.List;

/**
 * 描述：null 
 * 
 * @author auto_gen
 * @date 2023-01-13 15:51
 **/
@Data
public class SscUpdateSchemeReqBO extends BaseReqBo {
	private static final long serialVersionUID =  7093630879715712282L;

	/**
	 * 方案id
	 */
	private Long schemeId;
	/**
	 * 方案编号
	 */
	private String schemeCode;
	/**
	 * 方案名称
	 */
	private String schemeName;
	/**
	 * 方案类别
	 */
	private Integer schemeClass;
	/**
	 * 方案状态
	 */
	private String schemeStatus;
	/**
	 * 采购方式
	 */
	private Integer purchaseType;
	/**
	 * 资格审查方式
	 */
	private Integer checkType;
	/**
	 * 投标报价方式
	 */
	private Integer offerType;
	/**
	 * 是否必须招标
	 */
	private Integer biddingFlag;
	/**
	 * 是否唱标前显示供应商名称
	 */
	private Integer supplierNameDisplayFlag;
	/**
	 * 币种编码
	 */
	private String moneyTypeCode;
	/**
	 * 币种名称
	 */
	private String moneyTypeName;
	/**
	 * 采购组织形式
	 */
	private String organizationForm;
	/**
	 * 采购代理机构
	 */
	private String agencyCode;
	/**
	 * 采购代理机构名称
	 */
	private String agencyName;
	/**
	 * 是否分包(标段)
	 */
	private Integer subpackageFlag;
	/**
	 * 保证金金额
	 */
	private BigDecimal bidMarginAmount;
	/**
	 * 标书费用
	 */
	private BigDecimal tenderCost;
	/**
	 * 预计总金额
	 */
	private BigDecimal estAmount;
	/**
	 * 供应商最少响应数
	 */
	private Integer minSupNum;
	/**
	 * 是否标书收费
	 */
	private Integer tenderChargeFlag;
	/**
	 * 标书收费形式
	 */
	private Integer tenderSaleForm;
	/**
	 * 是否收取投标保证金
	 */
	private Integer bidMarginFlag;
	/**
	 * 投标保证金收取形式
	 */
	private Integer bidMarginForm;
	/**
	 * 投标保证金缴纳形式
	 */
	private String bidMarginPayForm;
	/**
	 * 是否提交履约保证金
	 */
	private Integer prefMarginFlag;
	/**
	 * 是否进口
	 */
	private Integer importFlag;
	/**
	 * 是否紧急采购
	 */
	private Integer emergencyFlag;
	/**
	 * 合同签订方式
	 */
	private Integer contractSignFlag;
	/**
	 * 执行人名称
	 */
	private String implName;
	/**
	 * 执行人ID
	 */
	private Long implId;
	/**
	 * 备注
	 */
	private String remark;
	/**
	 * 机构树路径
	 */
	private String orgPath;
	/**
	 * 租户ID
	 */
	private Long tenantId;
	/**
	 * 用户ID
	 */
	private Long userId;
	/**
	 * 用户账号
	 */
	private String username;
	/**
	 * 机构ID
	 */
	private Long orgId;
	/**
	 * 机构名称
	 */
	private String orgName;
	/**
	 * 附件信息
	 */
	private List<SscAccessoryBO> sscAccessory;
	/**
	 * 方案包信息
	 */
	private List<SscSchemePackBO> sscSchemePack;
	/**
	 * 令牌
	 */
	private String token;
	/**
	 * 是否草稿
	 */
	private Boolean enableDraft;
	/**
	 * 用户姓名
	 */
	private String name;
	/**
	 * 排序
	 */
	private String orderBy;

}

==> ssc-center-api-3.2.2-CLOUD-DEV-20240326.033328-1-sources.jar: com/tydic/dyc/ssc/service/scheme/bo/SscUpdateSchemeReqBO.java <==
package com.tydic.dyc.ssc.service.scheme.bo;

import lombok.Data;
import com.tydic.dyc.base.bo.BaseReqBo;
import com.tydic.dyc.ssc.service.scheme.bo.SscAccessoryBO;
import com.tydic.dyc.ssc.service.scheme.bo.SscSchemePackBO;
import java.math.BigDecimal;
import java.util.List;

/**
 * 描述：null 
 * 
 * @author auto_gen
 * @date 2023-03-13 14:26
 **/
@Data
public class SscUpdateSchemeReqBO extends BaseReqBo {
	private static final long serialVersionUID =  -5876760133414521886L;

	/**
	 * 方案id
	 */
	private Long schemeId;
	/**
	 * 方案编码
	 */
	private String schemeCode;
	/**
	 * 方案名称
	 */
	private String schemeName;
	/**
	 * 方案类别
	 */
	private Integer schemeClass;
	/**
	 * 方案状态
	 */
	private String schemeStatus;
	/**
	 * 采购方式
	 */
	private Integer purchaseType;
	/**
	 * 资格审查方式
	 */
	private Integer checkType;
	/**
	 * 投标报价方式
	 */
	private Integer offerType;
	/**
	 * 是否必须招标
	 */
	private Integer biddingFlag;
	/**
	 * 是否唱标前显示供应商名称
	 */
	private Integer supplierNameDisplayFlag;
	/**
	 * 币种编码
	 */
	private String moneyTypeCode;
	/**
	 * 币种名称
	 */
	private String moneyTypeName;
	/**
	 * 采购组织形式
	 */
	private String organizationForm;
	/**
	 * 采购代理机构
	 */
	private String agencyCode;
	/**
	 * 采购代理机构名称
	 */
	private String agencyName;
	/**
	 * 是否分包(标段)
	 */
	private Integer subpackageFlag;
	/**
	 * 保证金金额
	 */
	private BigDecimal bidMarginAmount;
	/**
	 * 标书费用
	 */
	private BigDecimal tenderCost;
	/**
	 * 预计总金额
	 */
	private BigDecimal estAmount;
	/**
	 * 供应商最少响应数
	 */
	private Integer minSupNum;
	/**
	 * 是否标书收费
	 */
	private Integer tenderChargeFlag;
	/**
	 * 标书收费形式
	 */
	private Integer tenderSaleForm;
	/**
	 * 是否收取投标保证金
	 */
	private Integer bidMarginFlag;
	/**
	 * 投标保证金收取形式
	 */
	private Integer bidMarginForm;
	/**
	 * 投标保证金缴纳形式
	 */
	private String bidMarginPayForm;
	/**
	 * 是否提交履约保证金
	 */
	private Integer prefMarginFlag;
	/**
	 * 是否进口
	 */
	private Integer importFlag;
	/**
	 * 是否紧急采购
	 */
	private Integer emergencyFlag;
	/**
	 * 合同签订方式
	 */
	private Integer contractSignFlag;
	/**
	 * 执行人名称
	 */
	private String implName;
	/**
	 * 执行人ID
	 */
	private Long implId;
	/**
	 * 备注
	 */
	private String remark;
	/**
	 * 机构树路径
	 */
	private String orgPath;
	/**
	 * 租户ID
	 */
	private Long tenantId;
	/**
	 * 用户ID
	 */
	private Long userId;
	/**
	 * 用户账号
	 */
	private String username;
	/**
	 * 机构ID
	 */
	private Long orgId;
	/**
	 * 机构名称
	 */
	private String orgName;
	/**
	 * 附件信息
	 */
	private List<SscAccessoryBO> sscAccessory;
	/**
	 * 方案包信息
	 */
	private List<SscSchemePackBO> sscSchemePack;
	/**
	 * 令牌
	 */
	private String token;
	/**
	 * 是否草稿
	 */
	private Boolean enableDraft;
	/**
	 * 用户姓名
	 */
	private String name;
	/**
	 * 审批状态
	 */
	private String schemeAuditStatus;
	/**
	 * 方案类型
	 */
	private String schemeType;
	/**
	 * 寻源方式
	 */
	private String sourcingWay;
	/**
	 * 是否支持一标多授
	 */
	private Integer multipleAwardsForOneBid;
	/**
	 * 执行状态
	 */
	private String schemeExectStatus;
	/**
	 * 执行状态翻译
	 */
	private String schemeExectStatusStr;
	/**
	 * 方案编号
	 */
	private String schemeNo;
	/**
	 * 创建人单位单位编码
	 */
	private String createOrgCode;
	/**
	 * 创建人公司ID
	 */
	private String createCompanyId;
	/**
	 * 创建人公司编码
	 */
	private String createCompanyCode;
	/**
	 * 创建人公司名称
	 */
	private String createCompanyName;
	/**
	 * 执行人编码
	 */
	private String implCode;
	/**
	 *  置空标识
	 */
	private Boolean nullFlag;
	/**
	 * 排序
	 */
	private String orderBy;

}
